[tor-commits] [stem/master] Including stem prefix for paths in stem comments

atagar at torproject.org atagar at torproject.org
Sun Nov 13 23:42:29 UTC 2011


commit fc562144fd8a333ad517575976328bc2dc3cec5d
Author: Damian Johnson <atagar at torproject.org>
Date:   Sun Nov 13 13:43:59 2011 -0800

    Including stem prefix for paths in stem comments
---
 test/integ/message.py              |    4 ++--
 test/integ/system.py               |   13 +++++++------
 test/unit/types/control_line.py    |    4 ++--
 test/unit/types/control_message.py |    6 +++---
 test/unit/types/version.py         |    4 ++--
 5 files changed, 16 insertions(+), 15 deletions(-)

diff --git a/test/integ/message.py b/test/integ/message.py
index a562f86..a8e722d 100644
--- a/test/integ/message.py
+++ b/test/integ/message.py
@@ -1,5 +1,5 @@
 """
-Integration tests for the types.ControlMessage class.
+Integration tests for the stem.types.ControlMessage class.
 """
 
 import re
@@ -11,7 +11,7 @@ import test.runner
 
 class TestMessageFunctions(unittest.TestCase):
   """
   Exercises the 'types.ControlMessage' class with an actual tor instance.
   """
   
   def test_unestablished_socket(self):
@@ -11,7 +11,7 @@ import test.runner
 class TestMessageFunctions(unittest.TestCase):
   """
-  Exercises the 'types.ControlMessage' class with an actual tor instance.
+  Exercises the 'stem.types.ControlMessage' class with an actual tor instance.
   """
   
diff --git a/test/integ/system.py b/test/integ/system.py
index 09ffd24..32ac892 100644
--- a/test/integ/system.py
+++ b/test/integ/system.py
@@ -1,5 +1,5 @@
 """
-Unit tests for the util.system functions in the context of a tor process.
+Unit tests for the stem.util.system functions in the context of a tor process.
 """
 
 import os
@@ -10,12 +10,13 @@ import stem.util.system as system
 
 class TestSystemFunctions(unittest.TestCase):
   """
-  Tests the util.system functions against the tor process that we're running.
+  Tests the stem.util.system functions against the tor process that we're
+  running.
   """
   
   def test_is_available(self):
     """
-    Checks the util.system.is_available function.
+    Checks the stem.util.system.is_available function.
     """
     
     # since we're running tor it would be kinda sad if this didn't detect it
@@ -26,7 +27,7 @@ class TestSystemFunctions(unittest.TestCase):
   
   def test_is_running(self):
     """
-    Checks the util.system.is_running function.
+    Checks the stem.util.system.is_running function.
     """
     
     self.assertTrue(system.is_running("tor"))
@@ -34,7 +35,7 @@ class TestSystemFunctions(unittest.TestCase):
 
   def test_get_pid(self):
     """
-    Checks the util.system.get_pid function.
+    Checks the stem.util.system.get_pid function.
     """
     
     runner = test.runner.get_runner()
@@ -43,7 +44,7 @@ class TestSystemFunctions(unittest.TestCase):
   
   def test_get_cwd(self):
     """
-    Checks the util.system.get_cwd function.
+    Checks the stem.util.system.get_cwd function.
     """
     
     # tor's pwd will match our process since we started it
diff --git a/test/unit/types/control_line.py b/test/unit/types/control_line.py
index bacda76..0c324e5 100644
--- a/test/unit/types/control_line.py
+++ b/test/unit/types/control_line.py
@@ -1,5 +1,5 @@
 """
-Unit tests for the types.ControlLine class.
+Unit tests for the stem.types.ControlLine class.
 """
 
 import unittest
@@ -15,7 +15,7 @@ PROTOCOLINFO_RESPONSE = (
 
 class TestControlLine(unittest.TestCase):
   """
   Tests methods of the types.ControlLine class.
   """
   
   def test_pop_examples(self):
@@ -15,7 +15,7 @@ PROTOCOLINFO_RESPONSE = (
 class TestControlLine(unittest.TestCase):
   """
-  Tests methods of the types.ControlLine class.
+  Tests methods of the stem.types.ControlLine class.
   """
   
diff --git a/test/unit/types/control_message.py b/test/unit/types/control_message.py
index 5e9b7bc..af8fa00 100644
--- a/test/unit/types/control_message.py
+++ b/test/unit/types/control_message.py
@@ -1,5 +1,5 @@
 """
-Unit tests for the types.ControlMessage parsing and class.
+Unit tests for the stem.types.ControlMessage parsing and class.
 """
 
 import socket
@@ -31,7 +31,7 @@ version -- The current version of Tor.
 
 class TestControlMessage(unittest.TestCase):
   """
   Tests methods and functions related to 'types.ControlMessage'. This uses
   StringIO to make 'files' to mock socket input.
   """
   
@@ -163,7 +163,7 @@ class TestControlMessage(unittest.TestCase):
     Performs some basic sanity checks that a reply mirrors its parsed result.
     
     Returns:
       types.ControlMessage for the given input
     """
     
     message = stem.types.read_message(StringIO.StringIO(controller_reply))
@@ -31,7 +31,7 @@ version -- The current version of Tor.
 class TestControlMessage(unittest.TestCase):
   """
-  Tests methods and functions related to 'types.ControlMessage'. This uses
+  Tests methods and functions related to 'stem.types.ControlMessage'. This uses
   StringIO to make 'files' to mock socket input.
   """
@@ -163,7 +163,7 @@ class TestControlMessage(unittest.TestCase):
     
     Returns:
-      types.ControlMessage for the given input
+      stem.types.ControlMessage for the given input
     """
     
diff --git a/test/unit/types/version.py b/test/unit/types/version.py
index fb04641..309ee07 100644
--- a/test/unit/types/version.py
+++ b/test/unit/types/version.py
@@ -1,5 +1,5 @@
 """
-Unit tests for the types.Version parsing and class.
+Unit tests for the stem.types.Version parsing and class.
 """
 
 import unittest
@@ -7,7 +7,7 @@ import stem.types
 
 class TestVerion(unittest.TestCase):
   """
   Tests methods and functions related to 'types.Version'.
   """
   
   def test_parsing(self):
@@ -7,7 +7,7 @@ import stem.types
 class TestVerion(unittest.TestCase):
   """
-  Tests methods and functions related to 'types.Version'.
+  Tests methods and functions related to 'stem.types.Version'.
   """
   





More information about the tor-commits mailing list